# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .scans import (
    ScansResource,
    AsyncScansResource,
    ScansResourceWithRawResponse,
    AsyncScansResourceWithRawResponse,
    ScansResourceWithStreamingResponse,
    AsyncScansResourceWithStreamingResponse,
)
from .requests import (
    RequestsResource,
    AsyncRequestsResource,
    RequestsResourceWithRawResponse,
    AsyncRequestsResourceWithRawResponse,
    RequestsResourceWithStreamingResponse,
    AsyncRequestsResourceWithStreamingResponse,
)
from .threat_events import (
    ThreatEventsResource,
    AsyncThreatEventsResource,
    ThreatEventsResourceWithRawResponse,
    AsyncThreatEventsResourceWithRawResponse,
    ThreatEventsResourceWithStreamingResponse,
    AsyncThreatEventsResourceWithStreamingResponse,
)
from .binary_storage import (
    BinaryStorageResource,
    AsyncBinaryStorageResource,
    BinaryStorageResourceWithRawResponse,
    AsyncBinaryStorageResourceWithRawResponse,
    BinaryStorageResourceWithStreamingResponse,
    AsyncBinaryStorageResourceWithStreamingResponse,
)
from .cloudforce_one import (
    CloudforceOneResource,
    AsyncCloudforceOneResource,
    CloudforceOneResourceWithRawResponse,
    AsyncCloudforceOneResourceWithRawResponse,
    CloudforceOneResourceWithStreamingResponse,
    AsyncCloudforceOneResourceWithStreamingResponse,
)

__all__ = [
    "ScansResource",
    "AsyncScansResource",
    "ScansResourceWithRawResponse",
    "AsyncScansResourceWithRawResponse",
    "ScansResourceWithStreamingResponse",
    "AsyncScansResourceWithStreamingResponse",
    "BinaryStorageResource",
    "AsyncBinaryStorageResource",
    "BinaryStorageResourceWithRawResponse",
    "AsyncBinaryStorageResourceWithRawResponse",
    "BinaryStorageResourceWithStreamingResponse",
    "AsyncBinaryStorageResourceWithStreamingResponse",
    "RequestsResource",
    "AsyncRequestsResource",
    "RequestsResourceWithRawResponse",
    "AsyncRequestsResourceWithRawResponse",
    "RequestsResourceWithStreamingResponse",
    "AsyncRequestsResourceWithStreamingResponse",
    "ThreatEventsResource",
    "AsyncThreatEventsResource",
    "ThreatEventsResourceWithRawResponse",
    "AsyncThreatEventsResourceWithRawResponse",
    "ThreatEventsResourceWithStreamingResponse",
    "AsyncThreatEventsResourceWithStreamingResponse",
    "CloudforceOneResource",
    "AsyncCloudforceOneResource",
    "CloudforceOneResourceWithRawResponse",
    "AsyncCloudforceOneResourceWithRawResponse",
    "CloudforceOneResourceWithStreamingResponse",
    "AsyncCloudforceOneResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["BodyScanningSettings"]


class BodyScanningSettings(BaseModel):
    """Specify the DLP inspection mode."""

    inspection_mode: Optional[Literal["deep", "shallow"]] = None
    """Specify the inspection mode as either `deep` or `shallow`."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["PageTrendParams"]


class PageTrendParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    device_type: Required[Annotated[Literal["DESKTOP", "MOBILE"], PropertyInfo(alias="deviceType")]]
    """The type of device."""

    metrics: Required[str]
    """A comma-separated list of metrics to include in the results."""

    region: Required[
        Literal[
            "asia-east1",
            "asia-northeast1",
            "asia-northeast2",
            "asia-south1",
            "asia-southeast1",
            "australia-southeast1",
            "europe-north1",
            "europe-southwest1",
            "europe-west1",
            "europe-west2",
            "europe-west3",
            "europe-west4",
            "europe-west8",
            "europe-west9",
            "me-west1",
            "southamerica-east1",
            "us-central1",
            "us-east1",
            "us-east4",
            "us-south1",
            "us-west1",
        ]
    ]
    """A test region."""

    start: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]

    tz: Required[str]
    """The timezone of the start and end timestamps."""

    end: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ....pagination import SyncV4PagePaginationArray, AsyncV4PagePaginationArray
from ...._base_client import AsyncPaginator, make_request_options
from ....types.zero_trust.access import custom_page_list_params, custom_page_create_params, custom_page_update_params
from ....types.zero_trust.access.custom_page import CustomPage
from ....types.zero_trust.access.custom_page_without_html import CustomPageWithoutHTML
from ....types.zero_trust.access.custom_page_delete_response import CustomPageDeleteResponse

__all__ = ["CustomPagesResource", "AsyncCustomPagesResource"]


class CustomPagesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CustomPagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return CustomPagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CustomPagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return CustomPagesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        custom_html: str,
        name: str,
        type: Literal["identity_denied", "forbidden"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageWithoutHTML]:
        """
        Create a custom page

        Args:
          account_id: Identifier.

          custom_html: Custom page HTML.

          name: Custom page name.

          type: Custom page type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/access/custom_pages", account_id=account_id),
            body=maybe_transform(
                {
                    "custom_html": custom_html,
                    "name": name,
                    "type": type,
                },
                custom_page_create_params.CustomPageCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageWithoutHTML]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageWithoutHTML]], ResultWrapper[CustomPageWithoutHTML]),
        )

    def update(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        custom_html: str,
        name: str,
        type: Literal["identity_denied", "forbidden"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageWithoutHTML]:
        """
        Update a custom page

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          custom_html: Custom page HTML.

          name: Custom page name.

          type: Custom page type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return self._put(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            body=maybe_transform(
                {
                    "custom_html": custom_html,
                    "name": name,
                    "type": type,
                },
                custom_page_update_params.CustomPageUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageWithoutHTML]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageWithoutHTML]], ResultWrapper[CustomPageWithoutHTML]),
        )

    def list(
        self,
        *,
        account_id: str,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncV4PagePaginationArray[CustomPageWithoutHTML]:
        """
        List custom pages

        Args:
          account_id: Identifier.

          page: Page number of results.

          per_page: Number of results per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/access/custom_pages", account_id=account_id),
            page=SyncV4PagePaginationArray[CustomPageWithoutHTML],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    custom_page_list_params.CustomPageListParams,
                ),
            ),
            model=CustomPageWithoutHTML,
        )

    def delete(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageDeleteResponse]:
        """
        Delete a custom page

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return self._delete(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageDeleteResponse]], ResultWrapper[CustomPageDeleteResponse]),
        )

    def get(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPage]:
        """
        Fetches a custom page and also returns its HTML.

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPage]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPage]], ResultWrapper[CustomPage]),
        )


class AsyncCustomPagesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCustomPagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCustomPagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCustomPagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncCustomPagesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        custom_html: str,
        name: str,
        type: Literal["identity_denied", "forbidden"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageWithoutHTML]:
        """
        Create a custom page

        Args:
          account_id: Identifier.

          custom_html: Custom page HTML.

          name: Custom page name.

          type: Custom page type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/access/custom_pages", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "custom_html": custom_html,
                    "name": name,
                    "type": type,
                },
                custom_page_create_params.CustomPageCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageWithoutHTML]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageWithoutHTML]], ResultWrapper[CustomPageWithoutHTML]),
        )

    async def update(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        custom_html: str,
        name: str,
        type: Literal["identity_denied", "forbidden"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageWithoutHTML]:
        """
        Update a custom page

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          custom_html: Custom page HTML.

          name: Custom page name.

          type: Custom page type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return await self._put(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            body=await async_maybe_transform(
                {
                    "custom_html": custom_html,
                    "name": name,
                    "type": type,
                },
                custom_page_update_params.CustomPageUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageWithoutHTML]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageWithoutHTML]], ResultWrapper[CustomPageWithoutHTML]),
        )

    def list(
        self,
        *,
        account_id: str,
        page: int | Omit = omit,
        per_page: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[CustomPageWithoutHTML, AsyncV4PagePaginationArray[CustomPageWithoutHTML]]:
        """
        List custom pages

        Args:
          account_id: Identifier.

          page: Page number of results.

          per_page: Number of results per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/access/custom_pages", account_id=account_id),
            page=AsyncV4PagePaginationArray[CustomPageWithoutHTML],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    custom_page_list_params.CustomPageListParams,
                ),
            ),
            model=CustomPageWithoutHTML,
        )

    async def delete(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPageDeleteResponse]:
        """
        Delete a custom page

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return await self._delete(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPageDeleteResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPageDeleteResponse]], ResultWrapper[CustomPageDeleteResponse]),
        )

    async def get(
        self,
        custom_page_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[CustomPage]:
        """
        Fetches a custom page and also returns its HTML.

        Args:
          account_id: Identifier.

          custom_page_id: UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not custom_page_id:
            raise ValueError(f"Expected a non-empty value for `custom_page_id` but received {custom_page_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/access/custom_pages/{custom_page_id}",
                account_id=account_id,
                custom_page_id=custom_page_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[CustomPage]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[CustomPage]], ResultWrapper[CustomPage]),
        )


class CustomPagesResourceWithRawResponse:
    def __init__(self, custom_pages: CustomPagesResource) -> None:
        self._custom_pages = custom_pages

        self.create = to_raw_response_wrapper(
            custom_pages.create,
        )
        self.update = to_raw_response_wrapper(
            custom_pages.update,
        )
        self.list = to_raw_response_wrapper(
            custom_pages.list,
        )
        self.delete = to_raw_response_wrapper(
            custom_pages.delete,
        )
        self.get = to_raw_response_wrapper(
            custom_pages.get,
        )


class AsyncCustomPagesResourceWithRawResponse:
    def __init__(self, custom_pages: AsyncCustomPagesResource) -> None:
        self._custom_pages = custom_pages

        self.create = async_to_raw_response_wrapper(
            custom_pages.create,
        )
        self.update = async_to_raw_response_wrapper(
            custom_pages.update,
        )
        self.list = async_to_raw_response_wrapper(
            custom_pages.list,
        )
        self.delete = async_to_raw_response_wrapper(
            custom_pages.delete,
        )
        self.get = async_to_raw_response_wrapper(
            custom_pages.get,
        )


class CustomPagesResourceWithStreamingResponse:
    def __init__(self, custom_pages: CustomPagesResource) -> None:
        self._custom_pages = custom_pages

        self.create = to_streamed_response_wrapper(
            custom_pages.create,
        )
        self.update = to_streamed_response_wrapper(
            custom_pages.update,
        )
        self.list = to_streamed_response_wrapper(
            custom_pages.list,
        )
        self.delete = to_streamed_response_wrapper(
            custom_pages.delete,
        )
        self.get = to_streamed_response_wrapper(
            custom_pages.get,
        )


class AsyncCustomPagesResourceWithStreamingResponse:
    def __init__(self, custom_pages: AsyncCustomPagesResource) -> None:
        self._custom_pages = custom_pages

        self.create = async_to_streamed_response_wrapper(
            custom_pages.create,
        )
        self.update = async_to_streamed_response_wrapper(
            custom_pages.update,
        )
        self.list = async_to_streamed_response_wrapper(
            custom_pages.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            custom_pages.delete,
        )
        self.get = async_to_streamed_response_wrapper(
            custom_pages.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["OriginPostQuantumEncryptionUpdateParams"]


class OriginPostQuantumEncryptionUpdateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    value: Required[Literal["preferred", "supported", "off"]]
    """Value of the Origin Post Quantum Encryption Setting."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["PolishParam"]


class PolishParam(TypedDict, total=False):
    id: Literal["polish"]
    """Apply options from the Polish feature of the Cloudflare Speed app."""

    value: Literal["off", "lossless", "lossy"]
    """The level of Polish you want applied to your origin."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["URLNormalizationUpdateParams"]


class URLNormalizationUpdateParams(TypedDict, total=False):
    zone_id: Required[str]
    """The unique ID of the zone."""

    scope: Required[Literal["incoming", "both", "none"]]
    """The scope of the URL normalization."""

    type: Required[Literal["cloudflare", "rfc3986"]]
    """The type of URL normalization performed by Cloudflare."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .domains import (
    DomainsResource,
    AsyncDomainsResource,
    DomainsResourceWithRawResponse,
    AsyncDomainsResourceWithRawResponse,
    DomainsResourceWithStreamingResponse,
    AsyncDomainsResourceWithStreamingResponse,
)
from .registrar import (
    RegistrarResource,
    AsyncRegistrarResource,
    RegistrarResourceWithRawResponse,
    AsyncRegistrarResourceWithRawResponse,
    RegistrarResourceWithStreamingResponse,
    AsyncRegistrarResourceWithStreamingResponse,
)
from .registrations import (
    RegistrationsResource,
    AsyncRegistrationsResource,
    RegistrationsResourceWithRawResponse,
    AsyncRegistrationsResourceWithRawResponse,
    RegistrationsResourceWithStreamingResponse,
    AsyncRegistrationsResourceWithStreamingResponse,
)
from .update_status import (
    UpdateStatusResource,
    AsyncUpdateStatusResource,
    UpdateStatusResourceWithRawResponse,
    AsyncUpdateStatusResourceWithRawResponse,
    UpdateStatusResourceWithStreamingResponse,
    AsyncUpdateStatusResourceWithStreamingResponse,
)
from .registration_status import (
    RegistrationStatusResource,
    AsyncRegistrationStatusResource,
    RegistrationStatusResourceWithRawResponse,
    AsyncRegistrationStatusResourceWithRawResponse,
    RegistrationStatusResourceWithStreamingResponse,
    AsyncRegistrationStatusResourceWithStreamingResponse,
)

__all__ = [
    "DomainsResource",
    "AsyncDomainsResource",
    "DomainsResourceWithRawResponse",
    "AsyncDomainsResourceWithRawResponse",
    "DomainsResourceWithStreamingResponse",
    "AsyncDomainsResourceWithStreamingResponse",
    "RegistrationsResource",
    "AsyncRegistrationsResource",
    "RegistrationsResourceWithRawResponse",
    "AsyncRegistrationsResourceWithRawResponse",
    "RegistrationsResourceWithStreamingResponse",
    "AsyncRegistrationsResourceWithStreamingResponse",
    "RegistrationStatusResource",
    "AsyncRegistrationStatusResource",
    "RegistrationStatusResourceWithRawResponse",
    "AsyncRegistrationStatusResourceWithRawResponse",
    "RegistrationStatusResourceWithStreamingResponse",
    "AsyncRegistrationStatusResourceWithStreamingResponse",
    "UpdateStatusResource",
    "AsyncUpdateStatusResource",
    "UpdateStatusResourceWithRawResponse",
    "AsyncUpdateStatusResourceWithRawResponse",
    "UpdateStatusResourceWithStreamingResponse",
    "AsyncUpdateStatusResourceWithStreamingResponse",
    "RegistrarResource",
    "AsyncRegistrarResource",
    "RegistrarResourceWithRawResponse",
    "AsyncRegistrarResourceWithRawResponse",
    "RegistrarResourceWithStreamingResponse",
    "AsyncRegistrarResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["SettingEditParams", "PayloadLogging"]


class SettingEditParams(TypedDict, total=False):
    account_id: Required[str]

    ai_context_analysis: Optional[bool]
    """Whether AI context analysis is enabled at the account level."""

    ocr: Optional[bool]
    """Whether OCR is enabled at the account level."""

    payload_logging: PayloadLogging
    """
    Request model for payload log settings within the DLP settings endpoint. Unlike
    the legacy endpoint, null and missing are treated identically here (both mean
    "not provided" for PATCH, "reset to default" for PUT).
    """


class PayloadLogging(TypedDict, total=False):
    """
    Request model for payload log settings within the DLP settings endpoint.
    Unlike the legacy endpoint, null and missing are treated identically here
    (both mean "not provided" for PATCH, "reset to default" for PUT).
    """

    masking_level: Literal["full", "partial", "clear", "default"]
    """Masking level for payload logs.

    - `full`: The entire payload is masked.
    - `partial`: Only partial payload content is masked.
    - `clear`: No masking is applied to the payload content.
    - `default`: DLP uses its default masking behavior.
    """

    public_key: Optional[str]
    """Base64-encoded public key for encrypting payload logs.

    - Set to a non-empty base64 string to enable payload logging with the given key.
    - Set to an empty string to disable payload logging.
    - Omit or set to null to leave unchanged (PATCH) or reset to disabled (PUT).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ....._models import BaseModel

__all__ = ["ConnectionGetResponse", "Conn"]


class Conn(BaseModel):
    id: Optional[str] = None
    """UUID of the Cloudflare Tunnel connection."""

    client_id: Optional[str] = None
    """UUID of the Cloudflare Tunnel connector."""

    client_version: Optional[str] = None
    """The cloudflared version used to establish this connection."""

    colo_name: Optional[str] = None
    """The Cloudflare data center used for this connection."""

    opened_at: Optional[datetime] = None
    """Timestamp of when the connection was established."""

    origin_ip: Optional[str] = None
    """The public IP address of the host running WARP Connector."""


class ConnectionGetResponse(BaseModel):
    """
    A WARP Connector client that maintains a connection to a Cloudflare data center.
    """

    id: Optional[str] = None
    """UUID of the Cloudflare Tunnel connector."""

    arch: Optional[str] = None
    """The cloudflared OS architecture used to establish this connection."""

    conns: Optional[List[Conn]] = None
    """
    The WARP Connector Tunnel connections between your origin and Cloudflare's edge.
    """

    features: Optional[List[str]] = None
    """Features enabled for the Cloudflare Tunnel."""

    ha_status: Optional[Literal["offline", "passive", "active"]] = None
    """The HA status of a WARP Connector client."""

    run_at: Optional[datetime] = None
    """Timestamp of when the tunnel connection was started."""

    version: Optional[str] = None
    """The cloudflared version used to establish this connection."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ...._models import BaseModel
from .wan_static_addressing import WANStaticAddressing

__all__ = ["WAN"]


class WAN(BaseModel):
    id: Optional[str] = None
    """Identifier"""

    health_check_rate: Optional[Literal["low", "mid", "high"]] = None
    """Magic WAN health check rate for tunnels created on this link.

    The default value is `mid`.
    """

    name: Optional[str] = None

    physport: Optional[int] = None

    priority: Optional[int] = None
    """Priority of WAN for traffic loadbalancing."""

    site_id: Optional[str] = None
    """Identifier"""

    static_addressing: Optional[WANStaticAddressing] = None
    """(optional) if omitted, use DHCP.

    Submit secondary_address when site is in high availability mode.
    """

    vlan_tag: Optional[int] = None
    """VLAN ID. Use zero for untagged."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Iterable
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    to_custom_raw_response_wrapper,
    async_to_streamed_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.url_scanner import scan_list_params, scan_create_params, scan_screenshot_params, scan_bulk_create_params
from ...types.url_scanner.scan_get_response import ScanGetResponse
from ...types.url_scanner.scan_har_response import ScanHARResponse
from ...types.url_scanner.scan_list_response import ScanListResponse
from ...types.url_scanner.scan_create_response import ScanCreateResponse
from ...types.url_scanner.scan_bulk_create_response import ScanBulkCreateResponse

__all__ = ["ScansResource", "AsyncScansResource"]


class ScansResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ScansResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return ScansResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ScansResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return ScansResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        account_id: str,
        url: str,
        agent_readiness: bool | Omit = omit,
        country: Literal[
            "AF",
            "AL",
            "DZ",
            "AD",
            "AO",
            "AG",
            "AR",
            "AM",
            "AU",
            "AT",
            "AZ",
            "BH",
            "BD",
            "BB",
            "BY",
            "BE",
            "BZ",
            "BJ",
            "BM",
            "BT",
            "BO",
            "BA",
            "BW",
            "BR",
            "BN",
            "BG",
            "BF",
            "BI",
            "KH",
            "CM",
            "CA",
            "CV",
            "KY",
            "CF",
            "TD",
            "CL",
            "CN",
            "CO",
            "KM",
            "CG",
            "CR",
            "CI",
            "HR",
            "CU",
            "CY",
            "CZ",
            "CD",
            "DK",
            "DJ",
            "DM",
            "DO",
            "EC",
            "EG",
            "SV",
            "GQ",
            "ER",
            "EE",
            "SZ",
            "ET",
            "FJ",
            "FI",
            "FR",
            "GA",
            "GE",
            "DE",
            "GH",
            "GR",
            "GL",
            "GD",
            "GT",
            "GN",
            "GW",
            "GY",
            "HT",
            "HN",
            "HU",
            "IS",
            "IN",
            "ID",
            "IR",
            "IQ",
            "IE",
            "IL",
            "IT",
            "JM",
            "JP",
            "JO",
            "KZ",
            "KE",
            "KI",
            "KW",
            "KG",
            "LA",
            "LV",
            "LB",
            "LS",
            "LR",
            "LY",
            "LI",
            "LT",
            "LU",
            "MO",
            "MG",
            "MW",
            "MY",
            "MV",
            "ML",
            "MR",
            "MU",
            "MX",
            "FM",
            "MD",
            "MC",
            "MN",
            "MS",
            "MA",
            "MZ",
            "MM",
            "NA",
            "NR",
            "NP",
            "NL",
            "NZ",
            "NI",
            "NE",
            "NG",
            "KP",
            "MK",
            "NO",
            "OM",
            "PK",
            "PS",
            "PA",
            "PG",
            "PY",
            "PE",
            "PH",
            "PL",
            "PT",
            "QA",
            "RO",
            "RU",
            "RW",
            "SH",
            "KN",
            "LC",
            "VC",
            "WS",
            "SM",
            "ST",
            "SA",
            "SN",
            "RS",
            "SC",
            "SL",
            "SK",
            "SI",
            "SB",
            "SO",
            "ZA",
            "KR",
            "SS",
            "ES",
            "LK",
            "SD",
            "SR",
            "SE",
            "CH",
            "SY",
            "TW",
            "TJ",
            "TZ",
            "TH",
            "BS",
            "GM",
            "TL",
            "TG",
            "TO",
            "TT",
            "TN",
            "TR",
            "TM",
            "UG",
            "UA",
            "AE",
            "GB",
            "US",
            "UY",
            "UZ",
            "VU",
            "VE",
            "VN",
            "YE",
            "ZM",
            "ZW",
        ]
        | Omit = omit,
        customagent: str | Omit = omit,
        custom_headers: Dict[str, str] | Omit = omit,
        referer: str | Omit = omit,
        screenshots_resolutions: List[Literal["desktop", "mobile", "tablet"]] | Omit = omit,
        visibility: Literal["Public", "Unlisted"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanCreateResponse:
        """Submit a URL to scan.

        Check limits at
        https://developers.cloudflare.com/security-center/investigate/scan-limits/.

        Args:
          account_id: Account ID.

          agent_readiness: Enable agent readiness checks.

          country: Country to geo egress from

          custom_headers: Set custom headers.

          screenshots_resolutions: Take multiple screenshots targeting different device types.

          visibility: The option `Public` means it will be included in listings like recent scans and
              search results. `Unlisted` means it will not be included in the aforementioned
              listings, users will need to have the scan's ID to access it. A a scan will be
              automatically marked as unlisted if it fails, if it contains potential PII or
              other sensitive material.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/urlscanner/v2/scan", account_id=account_id),
            body=maybe_transform(
                {
                    "url": url,
                    "agent_readiness": agent_readiness,
                    "country": country,
                    "customagent": customagent,
                    "custom_headers": custom_headers,
                    "referer": referer,
                    "screenshots_resolutions": screenshots_resolutions,
                    "visibility": visibility,
                },
                scan_create_params.ScanCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanCreateResponse,
        )

    def list(
        self,
        *,
        account_id: str,
        q: str | Omit = omit,
        size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanListResponse:
        """Use a subset of ElasticSearch Query syntax to filter scans.

        Some example
        queries:<br/> <br/>- 'path:"/bundles/jquery.js"': Searches for scans who
        requested resources with the given path.<br/>- 'page.asn:AS24940 AND hash:xxx':
        Websites hosted in AS24940 where a resource with the given hash was
        downloaded.<br/>- 'page.domain:microsoft\\** AND verdicts.malicious:true AND NOT
        page.domain:microsoft.com': malicious scans whose hostname starts with
        "microsoft".<br/>- 'apikey:me AND date:[2025-01 TO 2025-02]': my scans from 2025
        January to 2025 February.

        Args:
          account_id: Account ID.

          q: Filter scans

          size: Limit the number of objects in the response.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/search", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "q": q,
                        "size": size,
                    },
                    scan_list_params.ScanListParams,
                ),
            ),
            cast_to=ScanListResponse,
        )

    def bulk_create(
        self,
        *,
        account_id: str,
        body: Iterable[scan_bulk_create_params.Body] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanBulkCreateResponse:
        """Submit URLs to scan.

        Check limits at
        https://developers.cloudflare.com/security-center/investigate/scan-limits/ and
        take into account scans submitted in bulk have lower priority and may take
        longer to finish.

        Args:
          account_id: Account ID.

          body: List of urls to scan (up to a 100).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._post(
            path_template("/accounts/{account_id}/urlscanner/v2/bulk", account_id=account_id),
            body=maybe_transform(body, Iterable[scan_bulk_create_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanBulkCreateResponse,
        )

    def dom(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Returns a plain text response, with the scan's DOM content as rendered by
        Chrome.

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/dom/{scan_id}", account_id=account_id, scan_id=scan_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def get(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanGetResponse:
        """
        Get URL scan by uuid

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/urlscanner/v2/result/{scan_id}", account_id=account_id, scan_id=scan_id
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanGetResponse,
        )

    def har(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanHARResponse:
        """Get a URL scan's HAR file.

        See HAR spec at
        http://www.softwareishard.com/blog/har-12-spec/.

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        return self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/har/{scan_id}", account_id=account_id, scan_id=scan_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanHARResponse,
        )

    def screenshot(
        self,
        scan_id: str,
        *,
        account_id: str,
        resolution: Literal["desktop", "mobile", "tablet"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """
        Get scan's screenshot by resolution (desktop/mobile/tablet).

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          resolution: Target device type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        extra_headers = {"Accept": "image/png", **(extra_headers or {})}
        return self._get(
            path_template(
                "/accounts/{account_id}/urlscanner/v2/screenshots/{scan_id}.png", account_id=account_id, scan_id=scan_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"resolution": resolution}, scan_screenshot_params.ScanScreenshotParams),
            ),
            cast_to=BinaryAPIResponse,
        )


class AsyncScansResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncScansResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncScansResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncScansResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncScansResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        account_id: str,
        url: str,
        agent_readiness: bool | Omit = omit,
        country: Literal[
            "AF",
            "AL",
            "DZ",
            "AD",
            "AO",
            "AG",
            "AR",
            "AM",
            "AU",
            "AT",
            "AZ",
            "BH",
            "BD",
            "BB",
            "BY",
            "BE",
            "BZ",
            "BJ",
            "BM",
            "BT",
            "BO",
            "BA",
            "BW",
            "BR",
            "BN",
            "BG",
            "BF",
            "BI",
            "KH",
            "CM",
            "CA",
            "CV",
            "KY",
            "CF",
            "TD",
            "CL",
            "CN",
            "CO",
            "KM",
            "CG",
            "CR",
            "CI",
            "HR",
            "CU",
            "CY",
            "CZ",
            "CD",
            "DK",
            "DJ",
            "DM",
            "DO",
            "EC",
            "EG",
            "SV",
            "GQ",
            "ER",
            "EE",
            "SZ",
            "ET",
            "FJ",
            "FI",
            "FR",
            "GA",
            "GE",
            "DE",
            "GH",
            "GR",
            "GL",
            "GD",
            "GT",
            "GN",
            "GW",
            "GY",
            "HT",
            "HN",
            "HU",
            "IS",
            "IN",
            "ID",
            "IR",
            "IQ",
            "IE",
            "IL",
            "IT",
            "JM",
            "JP",
            "JO",
            "KZ",
            "KE",
            "KI",
            "KW",
            "KG",
            "LA",
            "LV",
            "LB",
            "LS",
            "LR",
            "LY",
            "LI",
            "LT",
            "LU",
            "MO",
            "MG",
            "MW",
            "MY",
            "MV",
            "ML",
            "MR",
            "MU",
            "MX",
            "FM",
            "MD",
            "MC",
            "MN",
            "MS",
            "MA",
            "MZ",
            "MM",
            "NA",
            "NR",
            "NP",
            "NL",
            "NZ",
            "NI",
            "NE",
            "NG",
            "KP",
            "MK",
            "NO",
            "OM",
            "PK",
            "PS",
            "PA",
            "PG",
            "PY",
            "PE",
            "PH",
            "PL",
            "PT",
            "QA",
            "RO",
            "RU",
            "RW",
            "SH",
            "KN",
            "LC",
            "VC",
            "WS",
            "SM",
            "ST",
            "SA",
            "SN",
            "RS",
            "SC",
            "SL",
            "SK",
            "SI",
            "SB",
            "SO",
            "ZA",
            "KR",
            "SS",
            "ES",
            "LK",
            "SD",
            "SR",
            "SE",
            "CH",
            "SY",
            "TW",
            "TJ",
            "TZ",
            "TH",
            "BS",
            "GM",
            "TL",
            "TG",
            "TO",
            "TT",
            "TN",
            "TR",
            "TM",
            "UG",
            "UA",
            "AE",
            "GB",
            "US",
            "UY",
            "UZ",
            "VU",
            "VE",
            "VN",
            "YE",
            "ZM",
            "ZW",
        ]
        | Omit = omit,
        customagent: str | Omit = omit,
        custom_headers: Dict[str, str] | Omit = omit,
        referer: str | Omit = omit,
        screenshots_resolutions: List[Literal["desktop", "mobile", "tablet"]] | Omit = omit,
        visibility: Literal["Public", "Unlisted"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanCreateResponse:
        """Submit a URL to scan.

        Check limits at
        https://developers.cloudflare.com/security-center/investigate/scan-limits/.

        Args:
          account_id: Account ID.

          agent_readiness: Enable agent readiness checks.

          country: Country to geo egress from

          custom_headers: Set custom headers.

          screenshots_resolutions: Take multiple screenshots targeting different device types.

          visibility: The option `Public` means it will be included in listings like recent scans and
              search results. `Unlisted` means it will not be included in the aforementioned
              listings, users will need to have the scan's ID to access it. A a scan will be
              automatically marked as unlisted if it fails, if it contains potential PII or
              other sensitive material.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/urlscanner/v2/scan", account_id=account_id),
            body=await async_maybe_transform(
                {
                    "url": url,
                    "agent_readiness": agent_readiness,
                    "country": country,
                    "customagent": customagent,
                    "custom_headers": custom_headers,
                    "referer": referer,
                    "screenshots_resolutions": screenshots_resolutions,
                    "visibility": visibility,
                },
                scan_create_params.ScanCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanCreateResponse,
        )

    async def list(
        self,
        *,
        account_id: str,
        q: str | Omit = omit,
        size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanListResponse:
        """Use a subset of ElasticSearch Query syntax to filter scans.

        Some example
        queries:<br/> <br/>- 'path:"/bundles/jquery.js"': Searches for scans who
        requested resources with the given path.<br/>- 'page.asn:AS24940 AND hash:xxx':
        Websites hosted in AS24940 where a resource with the given hash was
        downloaded.<br/>- 'page.domain:microsoft\\** AND verdicts.malicious:true AND NOT
        page.domain:microsoft.com': malicious scans whose hostname starts with
        "microsoft".<br/>- 'apikey:me AND date:[2025-01 TO 2025-02]': my scans from 2025
        January to 2025 February.

        Args:
          account_id: Account ID.

          q: Filter scans

          size: Limit the number of objects in the response.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/search", account_id=account_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "q": q,
                        "size": size,
                    },
                    scan_list_params.ScanListParams,
                ),
            ),
            cast_to=ScanListResponse,
        )

    async def bulk_create(
        self,
        *,
        account_id: str,
        body: Iterable[scan_bulk_create_params.Body] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanBulkCreateResponse:
        """Submit URLs to scan.

        Check limits at
        https://developers.cloudflare.com/security-center/investigate/scan-limits/ and
        take into account scans submitted in bulk have lower priority and may take
        longer to finish.

        Args:
          account_id: Account ID.

          body: List of urls to scan (up to a 100).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return await self._post(
            path_template("/accounts/{account_id}/urlscanner/v2/bulk", account_id=account_id),
            body=await async_maybe_transform(body, Iterable[scan_bulk_create_params.Body]),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanBulkCreateResponse,
        )

    async def dom(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Returns a plain text response, with the scan's DOM content as rendered by
        Chrome.

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/dom/{scan_id}", account_id=account_id, scan_id=scan_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def get(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanGetResponse:
        """
        Get URL scan by uuid

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/urlscanner/v2/result/{scan_id}", account_id=account_id, scan_id=scan_id
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanGetResponse,
        )

    async def har(
        self,
        scan_id: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ScanHARResponse:
        """Get a URL scan's HAR file.

        See HAR spec at
        http://www.softwareishard.com/blog/har-12-spec/.

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        return await self._get(
            path_template("/accounts/{account_id}/urlscanner/v2/har/{scan_id}", account_id=account_id, scan_id=scan_id),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ScanHARResponse,
        )

    async def screenshot(
        self,
        scan_id: str,
        *,
        account_id: str,
        resolution: Literal["desktop", "mobile", "tablet"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """
        Get scan's screenshot by resolution (desktop/mobile/tablet).

        Args:
          account_id: Account ID.

          scan_id: Scan UUID.

          resolution: Target device type.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not scan_id:
            raise ValueError(f"Expected a non-empty value for `scan_id` but received {scan_id!r}")
        extra_headers = {"Accept": "image/png", **(extra_headers or {})}
        return await self._get(
            path_template(
                "/accounts/{account_id}/urlscanner/v2/screenshots/{scan_id}.png", account_id=account_id, scan_id=scan_id
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"resolution": resolution}, scan_screenshot_params.ScanScreenshotParams
                ),
            ),
            cast_to=AsyncBinaryAPIResponse,
        )


class ScansResourceWithRawResponse:
    def __init__(self, scans: ScansResource) -> None:
        self._scans = scans

        self.create = to_raw_response_wrapper(
            scans.create,
        )
        self.list = to_raw_response_wrapper(
            scans.list,
        )
        self.bulk_create = to_raw_response_wrapper(
            scans.bulk_create,
        )
        self.dom = to_raw_response_wrapper(
            scans.dom,
        )
        self.get = to_raw_response_wrapper(
            scans.get,
        )
        self.har = to_raw_response_wrapper(
            scans.har,
        )
        self.screenshot = to_custom_raw_response_wrapper(
            scans.screenshot,
            BinaryAPIResponse,
        )


class AsyncScansResourceWithRawResponse:
    def __init__(self, scans: AsyncScansResource) -> None:
        self._scans = scans

        self.create = async_to_raw_response_wrapper(
            scans.create,
        )
        self.list = async_to_raw_response_wrapper(
            scans.list,
        )
        self.bulk_create = async_to_raw_response_wrapper(
            scans.bulk_create,
        )
        self.dom = async_to_raw_response_wrapper(
            scans.dom,
        )
        self.get = async_to_raw_response_wrapper(
            scans.get,
        )
        self.har = async_to_raw_response_wrapper(
            scans.har,
        )
        self.screenshot = async_to_custom_raw_response_wrapper(
            scans.screenshot,
            AsyncBinaryAPIResponse,
        )


class ScansResourceWithStreamingResponse:
    def __init__(self, scans: ScansResource) -> None:
        self._scans = scans

        self.create = to_streamed_response_wrapper(
            scans.create,
        )
        self.list = to_streamed_response_wrapper(
            scans.list,
        )
        self.bulk_create = to_streamed_response_wrapper(
            scans.bulk_create,
        )
        self.dom = to_streamed_response_wrapper(
            scans.dom,
        )
        self.get = to_streamed_response_wrapper(
            scans.get,
        )
        self.har = to_streamed_response_wrapper(
            scans.har,
        )
        self.screenshot = to_custom_streamed_response_wrapper(
            scans.screenshot,
            StreamedBinaryAPIResponse,
        )


class AsyncScansResourceWithStreamingResponse:
    def __init__(self, scans: AsyncScansResource) -> None:
        self._scans = scans

        self.create = async_to_streamed_response_wrapper(
            scans.create,
        )
        self.list = async_to_streamed_response_wrapper(
            scans.list,
        )
        self.bulk_create = async_to_streamed_response_wrapper(
            scans.bulk_create,
        )
        self.dom = async_to_streamed_response_wrapper(
            scans.dom,
        )
        self.get = async_to_streamed_response_wrapper(
            scans.get,
        )
        self.har = async_to_streamed_response_wrapper(
            scans.har,
        )
        self.screenshot = async_to_custom_streamed_response_wrapper(
            scans.screenshot,
            AsyncStreamedBinaryAPIResponse,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ....._models import BaseModel

__all__ = ["EveryoneRule", "Everyone"]


class Everyone(BaseModel):
    """An empty object which matches on all users."""

    pass


class EveryoneRule(BaseModel):
    """Matches everyone."""

    everyone: Everyone
    """An empty object which matches on all users."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .eligible import (
    EligibleResource,
    AsyncEligibleResource,
    EligibleResourceWithRawResponse,
    AsyncEligibleResourceWithRawResponse,
    EligibleResourceWithStreamingResponse,
    AsyncEligibleResourceWithStreamingResponse,
)
from .webhooks import (
    WebhooksResource,
    AsyncWebhooksResource,
    WebhooksResourceWithRawResponse,
    AsyncWebhooksResourceWithRawResponse,
    WebhooksResourceWithStreamingResponse,
    AsyncWebhooksResourceWithStreamingResponse,
)
from .pagerduty import (
    PagerdutyResource,
    AsyncPagerdutyResource,
    PagerdutyResourceWithRawResponse,
    AsyncPagerdutyResourceWithRawResponse,
    PagerdutyResourceWithStreamingResponse,
    AsyncPagerdutyResourceWithStreamingResponse,
)
from .destinations import (
    DestinationsResource,
    AsyncDestinationsResource,
    DestinationsResourceWithRawResponse,
    AsyncDestinationsResourceWithRawResponse,
    DestinationsResourceWithStreamingResponse,
    AsyncDestinationsResourceWithStreamingResponse,
)

__all__ = [
    "EligibleResource",
    "AsyncEligibleResource",
    "EligibleResourceWithRawResponse",
    "AsyncEligibleResourceWithRawResponse",
    "EligibleResourceWithStreamingResponse",
    "AsyncEligibleResourceWithStreamingResponse",
    "PagerdutyResource",
    "AsyncPagerdutyResource",
    "PagerdutyResourceWithRawResponse",
    "AsyncPagerdutyResourceWithRawResponse",
    "PagerdutyResourceWithStreamingResponse",
    "AsyncPagerdutyResourceWithStreamingResponse",
    "WebhooksResource",
    "AsyncWebhooksResource",
    "WebhooksResourceWithRawResponse",
    "AsyncWebhooksResourceWithRawResponse",
    "WebhooksResourceWithStreamingResponse",
    "AsyncWebhooksResourceWithStreamingResponse",
    "DestinationsResource",
    "AsyncDestinationsResource",
    "DestinationsResourceWithRawResponse",
    "AsyncDestinationsResourceWithRawResponse",
    "DestinationsResourceWithStreamingResponse",
    "AsyncDestinationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .token import (
    TokenResource,
    AsyncTokenResource,
    TokenResourceWithRawResponse,
    AsyncTokenResourceWithRawResponse,
    TokenResourceWithStreamingResponse,
    AsyncTokenResourceWithStreamingResponse,
)
from .failover import (
    FailoverResource,
    AsyncFailoverResource,
    FailoverResourceWithRawResponse,
    AsyncFailoverResourceWithRawResponse,
    FailoverResourceWithStreamingResponse,
    AsyncFailoverResourceWithStreamingResponse,
)
from .connectors import (
    ConnectorsResource,
    AsyncConnectorsResource,
    ConnectorsResourceWithRawResponse,
    AsyncConnectorsResourceWithRawResponse,
    ConnectorsResourceWithStreamingResponse,
    AsyncConnectorsResourceWithStreamingResponse,
)
from .connections import (
    ConnectionsResource,
    AsyncConnectionsResource,
    ConnectionsResourceWithRawResponse,
    AsyncConnectionsResourceWithRawResponse,
    ConnectionsResourceWithStreamingResponse,
    AsyncConnectionsResourceWithStreamingResponse,
)
from .warp_connector import (
    WARPConnectorResource,
    AsyncWARPConnectorResource,
    WARPConnectorResourceWithRawResponse,
    AsyncWARPConnectorResourceWithRawResponse,
    WARPConnectorResourceWithStreamingResponse,
    AsyncWARPConnectorResourceWithStreamingResponse,
)

__all__ = [
    "TokenResource",
    "AsyncTokenResource",
    "TokenResourceWithRawResponse",
    "AsyncTokenResourceWithRawResponse",
    "TokenResourceWithStreamingResponse",
    "AsyncTokenResourceWithStreamingResponse",
    "ConnectionsResource",
    "AsyncConnectionsResource",
    "ConnectionsResourceWithRawResponse",
    "AsyncConnectionsResourceWithRawResponse",
    "ConnectionsResourceWithStreamingResponse",
    "AsyncConnectionsResourceWithStreamingResponse",
    "ConnectorsResource",
    "AsyncConnectorsResource",
    "ConnectorsResourceWithRawResponse",
    "AsyncConnectorsResourceWithRawResponse",
    "ConnectorsResourceWithStreamingResponse",
    "AsyncConnectorsResourceWithStreamingResponse",
    "FailoverResource",
    "AsyncFailoverResource",
    "FailoverResourceWithRawResponse",
    "AsyncFailoverResourceWithRawResponse",
    "FailoverResourceWithStreamingResponse",
    "AsyncFailoverResourceWithStreamingResponse",
    "WARPConnectorResource",
    "AsyncWARPConnectorResource",
    "WARPConnectorResourceWithRawResponse",
    "AsyncWARPConnectorResourceWithRawResponse",
    "WARPConnectorResourceWithStreamingResponse",
    "AsyncWARPConnectorResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Type, Optional, cast
from typing_extensions import Literal

import httpx

from ....._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ....._utils import path_template, maybe_transform, async_maybe_transform
from ....._compat import cached_property
from .percentiles import (
    PercentilesResource,
    AsyncPercentilesResource,
    PercentilesResourceWithRawResponse,
    AsyncPercentilesResourceWithRawResponse,
    PercentilesResourceWithStreamingResponse,
    AsyncPercentilesResourceWithStreamingResponse,
)
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._wrappers import ResultWrapper
from ....._base_client import make_request_options
from .....types.zero_trust.dex import http_test_get_params
from .....types.zero_trust.dex.http_details import HTTPDetails

__all__ = ["HTTPTestsResource", "AsyncHTTPTestsResource"]


class HTTPTestsResource(SyncAPIResource):
    @cached_property
    def percentiles(self) -> PercentilesResource:
        return PercentilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> HTTPTestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return HTTPTestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HTTPTestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return HTTPTestsResourceWithStreamingResponse(self)

    def get(
        self,
        test_id: str,
        *,
        account_id: str,
        from_: str,
        interval: Literal["minute", "hour"],
        to: str,
        colo: str | Omit = omit,
        device_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[HTTPDetails]:
        """
        Get test details and aggregate performance metrics for an http test for a given
        time period between 1 hour and 7 days.

        Args:
          test_id: API Resource UUID tag.

          from_: Start time for aggregate metrics in ISO ms

          interval: Time interval for aggregate time slots.

          to: End time for aggregate metrics in ISO ms

          colo: Optionally filter result stats to a Cloudflare colo. Cannot be used in
              combination with deviceId param.

          device_id: Optionally filter result stats to a specific device(s). Cannot be used in
              combination with colo param.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not test_id:
            raise ValueError(f"Expected a non-empty value for `test_id` but received {test_id!r}")
        return self._get(
            path_template("/accounts/{account_id}/dex/http-tests/{test_id}", account_id=account_id, test_id=test_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "from_": from_,
                        "interval": interval,
                        "to": to,
                        "colo": colo,
                        "device_id": device_id,
                    },
                    http_test_get_params.HTTPTestGetParams,
                ),
                post_parser=ResultWrapper[Optional[HTTPDetails]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[HTTPDetails]], ResultWrapper[HTTPDetails]),
        )


class AsyncHTTPTestsResource(AsyncAPIResource):
    @cached_property
    def percentiles(self) -> AsyncPercentilesResource:
        return AsyncPercentilesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncHTTPTestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHTTPTestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHTTPTestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncHTTPTestsResourceWithStreamingResponse(self)

    async def get(
        self,
        test_id: str,
        *,
        account_id: str,
        from_: str,
        interval: Literal["minute", "hour"],
        to: str,
        colo: str | Omit = omit,
        device_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[HTTPDetails]:
        """
        Get test details and aggregate performance metrics for an http test for a given
        time period between 1 hour and 7 days.

        Args:
          test_id: API Resource UUID tag.

          from_: Start time for aggregate metrics in ISO ms

          interval: Time interval for aggregate time slots.

          to: End time for aggregate metrics in ISO ms

          colo: Optionally filter result stats to a Cloudflare colo. Cannot be used in
              combination with deviceId param.

          device_id: Optionally filter result stats to a specific device(s). Cannot be used in
              combination with colo param.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not test_id:
            raise ValueError(f"Expected a non-empty value for `test_id` but received {test_id!r}")
        return await self._get(
            path_template("/accounts/{account_id}/dex/http-tests/{test_id}", account_id=account_id, test_id=test_id),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "from_": from_,
                        "interval": interval,
                        "to": to,
                        "colo": colo,
                        "device_id": device_id,
                    },
                    http_test_get_params.HTTPTestGetParams,
                ),
                post_parser=ResultWrapper[Optional[HTTPDetails]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[HTTPDetails]], ResultWrapper[HTTPDetails]),
        )


class HTTPTestsResourceWithRawResponse:
    def __init__(self, http_tests: HTTPTestsResource) -> None:
        self._http_tests = http_tests

        self.get = to_raw_response_wrapper(
            http_tests.get,
        )

    @cached_property
    def percentiles(self) -> PercentilesResourceWithRawResponse:
        return PercentilesResourceWithRawResponse(self._http_tests.percentiles)


class AsyncHTTPTestsResourceWithRawResponse:
    def __init__(self, http_tests: AsyncHTTPTestsResource) -> None:
        self._http_tests = http_tests

        self.get = async_to_raw_response_wrapper(
            http_tests.get,
        )

    @cached_property
    def percentiles(self) -> AsyncPercentilesResourceWithRawResponse:
        return AsyncPercentilesResourceWithRawResponse(self._http_tests.percentiles)


class HTTPTestsResourceWithStreamingResponse:
    def __init__(self, http_tests: HTTPTestsResource) -> None:
        self._http_tests = http_tests

        self.get = to_streamed_response_wrapper(
            http_tests.get,
        )

    @cached_property
    def percentiles(self) -> PercentilesResourceWithStreamingResponse:
        return PercentilesResourceWithStreamingResponse(self._http_tests.percentiles)


class AsyncHTTPTestsResourceWithStreamingResponse:
    def __init__(self, http_tests: AsyncHTTPTestsResource) -> None:
        self._http_tests = http_tests

        self.get = async_to_streamed_response_wrapper(
            http_tests.get,
        )

    @cached_property
    def percentiles(self) -> AsyncPercentilesResourceWithStreamingResponse:
        return AsyncPercentilesResourceWithStreamingResponse(self._http_tests.percentiles)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .cloudflared_edit_params import CloudflaredEditParams as CloudflaredEditParams
from .cloudflared_list_params import CloudflaredListParams as CloudflaredListParams
from .cloudflared_create_params import CloudflaredCreateParams as CloudflaredCreateParams
from .warp_connector_edit_params import WARPConnectorEditParams as WARPConnectorEditParams
from .warp_connector_list_params import WARPConnectorListParams as WARPConnectorListParams
from .warp_connector_get_response import WARPConnectorGetResponse as WARPConnectorGetResponse
from .warp_connector_create_params import WARPConnectorCreateParams as WARPConnectorCreateParams
from .warp_connector_edit_response import WARPConnectorEditResponse as WARPConnectorEditResponse
from .warp_connector_list_response import WARPConnectorListResponse as WARPConnectorListResponse
from .warp_connector_create_response import WARPConnectorCreateResponse as WARPConnectorCreateResponse
from .warp_connector_delete_response import WARPConnectorDeleteResponse as WARPConnectorDeleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = [
    "RegistrationCreateParams",
    "Contacts",
    "ContactsRegistrant",
    "ContactsRegistrantPostalInfo",
    "ContactsRegistrantPostalInfoAddress",
]


class RegistrationCreateParams(TypedDict, total=False):
    account_id: Required[str]
    """Identifier"""

    domain_name: Required[str]
    """
    Fully qualified domain name (FQDN) including the extension (e.g., `example.com`,
    `mybrand.app`). The domain name uniquely identifies a registration — the same
    domain cannot be registered twice, making it a natural idempotency key for
    registration requests.
    """

    auto_renew: bool
    """Enable or disable automatic renewal.

    Defaults to `false` if omitted. Setting this field to `true` is an explicit
    opt-in authorizing Cloudflare to charge the account's default payment method up
    to 30 days before domain expiry to renew the domain automatically. Renewal
    pricing may change over time based on registry pricing.
    """

    contacts: Contacts
    """Contact data for the registration request.

    If the `contacts` object is omitted entirely from the request, or if
    `contacts.registrant` is not provided, the system will use the account's default
    address book entry as the registrant contact. This default must be
    pre-configured by the account owner at
    `https://dash.cloudflare.com/{account_id}/domains/registrations`, where they can
    create or update the address book entry and accept the required agreement. No
    API exists for managing address book entries at this time.

    If no default address book entry exists and no registrant contact is provided,
    the registration request will fail with a validation error.
    """

    privacy_mode: Literal["redaction"]
    """WHOIS privacy mode for the registration. Defaults to `redaction`.

    - `off`: Do not request WHOIS privacy.
    - `redaction`: Request WHOIS redaction where supported by the extension. Some
      extensions do not support privacy/redaction.
    """

    years: int
    """Number of years to register (1–10).

    If omitted, defaults to the minimum registration period required by the registry
    for this extension. For most extensions this is 1 year, but some extensions
    require longer minimum terms (e.g., `.ai` requires a minimum of 2 years).

    The registry for each extension may also enforce its own maximum registration
    term. If the requested value exceeds the registry's maximum, the registration
    will be rejected. When in doubt, use the default by omitting this field.
    """

    prefer: Annotated[str, PropertyInfo(alias="Prefer")]


class ContactsRegistrantPostalInfoAddress(TypedDict, total=False):
    """Physical mailing address for the registrant contact."""

    city: Required[str]
    """City or locality name."""

    country_code: Required[str]
    """Two-letter country code per ISO 3166-1 alpha-2 (e.g., `US`, `GB`, `CA`, `DE`)."""

    postal_code: Required[str]
    """Postal or ZIP code."""

    state: Required[str]
    """State, province, or region.

    Use the standard abbreviation where applicable (e.g., `TX` for Texas, `ON` for
    Ontario).
    """

    street: Required[str]
    """Street address including building/suite number."""


class ContactsRegistrantPostalInfo(TypedDict, total=False):
    """Postal/mailing information for the registrant contact."""

    address: Required[ContactsRegistrantPostalInfoAddress]
    """Physical mailing address for the registrant contact."""

    name: Required[str]
    """Full legal name of the registrant (individual or authorized representative)."""

    organization: str
    """Organization or company name. Optional for individual registrants."""


class ContactsRegistrant(TypedDict, total=False):
    """Registrant contact data for the domain registration.

    This information
    is submitted to the domain registry and, depending on extension and
    privacy settings, may appear in public WHOIS records.
    """

    email: Required[str]
    """Email address for the registrant.

    Used for domain-related communications from the registry, including ownership
    verification and renewal notices.
    """

    phone: Required[str]
    """
    Phone number in E.164 format: `+{country_code}.{number}` with no spaces or
    dashes. Examples: `+1.5555555555` (US), `+44.2071234567` (UK), `+81.312345678`
    (Japan).
    """

    postal_info: Required[ContactsRegistrantPostalInfo]
    """Postal/mailing information for the registrant contact."""

    fax: str
    """Fax number in E.164 format (e.g., `+1.5555555555`).

    Optional. Most registrations do not require a fax number.
    """


class Contacts(TypedDict, total=False):
    """Contact data for the registration request.

    If the `contacts` object is omitted entirely from the request, or if
    `contacts.registrant` is not provided, the system will use the account's
    default address book entry as the registrant contact. This default must be
    pre-configured by the account owner at
    `https://dash.cloudflare.com/{account_id}/domains/registrations`, where
    they can create or update the address book entry and accept the required
    agreement. No API exists for managing address book entries at this time.

    If no default address book entry exists and no registrant contact is
    provided, the registration request will fail with a validation error.
    """

    registrant: ContactsRegistrant
    """Registrant contact data for the domain registration.

    This information is submitted to the domain registry and, depending on extension
    and privacy settings, may appear in public WHOIS records.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing import Type, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import path_template, maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._wrappers import ResultWrapper
from ...pagination import SyncSinglePage, AsyncSinglePage
from ..._base_client import AsyncPaginator, make_request_options
from ...types.registrar import domain_update_params
from ...types.registrar.domain import Domain

__all__ = ["DomainsResource", "AsyncDomainsResource"]


class DomainsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DomainsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return DomainsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DomainsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return DomainsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    def update(
        self,
        domain_name: str,
        *,
        account_id: str,
        auto_renew: bool | Omit = omit,
        locked: bool | Omit = omit,
        privacy: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Update individual domain.

        Args:
          account_id: Identifier

          domain_name: Fully qualified domain name (FQDN) including the extension (e.g., `example.com`,
              `mybrand.app`). The domain name uniquely identifies a registration — the same
              domain cannot be registered twice, making it a natural idempotency key for
              registration requests.

          auto_renew: Auto-renew controls whether subscription is automatically renewed upon domain
              expiration.

          locked: Shows whether a registrar lock is in place for a domain.

          privacy: Privacy option controls redacting WHOIS information.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not domain_name:
            raise ValueError(f"Expected a non-empty value for `domain_name` but received {domain_name!r}")
        return self._put(
            path_template(
                "/accounts/{account_id}/registrar/domains/{domain_name}", account_id=account_id, domain_name=domain_name
            ),
            body=maybe_transform(
                {
                    "auto_renew": auto_renew,
                    "locked": locked,
                    "privacy": privacy,
                },
                domain_update_params.DomainUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncSinglePage[Domain]:
        """
        List domains handled by Registrar.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/registrar/domains", account_id=account_id),
            page=SyncSinglePage[Domain],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Domain,
        )

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    def get(
        self,
        domain_name: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Show individual domain.

        Args:
          account_id: Identifier

          domain_name: Fully qualified domain name (FQDN) including the extension (e.g., `example.com`,
              `mybrand.app`). The domain name uniquely identifies a registration — the same
              domain cannot be registered twice, making it a natural idempotency key for
              registration requests.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not domain_name:
            raise ValueError(f"Expected a non-empty value for `domain_name` but received {domain_name!r}")
        return self._get(
            path_template(
                "/accounts/{account_id}/registrar/domains/{domain_name}", account_id=account_id, domain_name=domain_name
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )


class AsyncDomainsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDomainsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDomainsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDomainsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncDomainsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    async def update(
        self,
        domain_name: str,
        *,
        account_id: str,
        auto_renew: bool | Omit = omit,
        locked: bool | Omit = omit,
        privacy: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Update individual domain.

        Args:
          account_id: Identifier

          domain_name: Fully qualified domain name (FQDN) including the extension (e.g., `example.com`,
              `mybrand.app`). The domain name uniquely identifies a registration — the same
              domain cannot be registered twice, making it a natural idempotency key for
              registration requests.

          auto_renew: Auto-renew controls whether subscription is automatically renewed upon domain
              expiration.

          locked: Shows whether a registrar lock is in place for a domain.

          privacy: Privacy option controls redacting WHOIS information.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not domain_name:
            raise ValueError(f"Expected a non-empty value for `domain_name` but received {domain_name!r}")
        return await self._put(
            path_template(
                "/accounts/{account_id}/registrar/domains/{domain_name}", account_id=account_id, domain_name=domain_name
            ),
            body=await async_maybe_transform(
                {
                    "auto_renew": auto_renew,
                    "locked": locked,
                    "privacy": privacy,
                },
                domain_update_params.DomainUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    def list(
        self,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Domain, AsyncSinglePage[Domain]]:
        """
        List domains handled by Registrar.

        Args:
          account_id: Identifier

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        return self._get_api_list(
            path_template("/accounts/{account_id}/registrar/domains", account_id=account_id),
            page=AsyncSinglePage[Domain],
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            model=Domain,
        )

    @typing_extensions.deprecated(
        "This operation is deprecated and will be removed in a future release. A replacement Registrar API will be announced separately."
    )
    async def get(
        self,
        domain_name: str,
        *,
        account_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Show individual domain.

        Args:
          account_id: Identifier

          domain_name: Fully qualified domain name (FQDN) including the extension (e.g., `example.com`,
              `mybrand.app`). The domain name uniquely identifies a registration — the same
              domain cannot be registered twice, making it a natural idempotency key for
              registration requests.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not account_id:
            raise ValueError(f"Expected a non-empty value for `account_id` but received {account_id!r}")
        if not domain_name:
            raise ValueError(f"Expected a non-empty value for `domain_name` but received {domain_name!r}")
        return await self._get(
            path_template(
                "/accounts/{account_id}/registrar/domains/{domain_name}", account_id=account_id, domain_name=domain_name
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                post_parser=ResultWrapper[Optional[object]]._unwrapper,
            ),
            cast_to=cast(Type[object], ResultWrapper[object]),
        )


class DomainsResourceWithRawResponse:
    def __init__(self, domains: DomainsResource) -> None:
        self._domains = domains

        self.update = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                domains.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                domains.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                domains.get,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncDomainsResourceWithRawResponse:
    def __init__(self, domains: AsyncDomainsResource) -> None:
        self._domains = domains

        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                domains.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                domains.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                domains.get,  # pyright: ignore[reportDeprecated],
            )
        )


class DomainsResourceWithStreamingResponse:
    def __init__(self, domains: DomainsResource) -> None:
        self._domains = domains

        self.update = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                domains.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                domains.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                domains.get,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncDomainsResourceWithStreamingResponse:
    def __init__(self, domains: AsyncDomainsResource) -> None:
        self._domains = domains

        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                domains.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.list = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                domains.list,  # pyright: ignore[reportDeprecated],
            )
        )
        self.get = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                domains.get,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["WaitingRoomRule"]


class WaitingRoomRule(BaseModel):
    id: Optional[str] = None
    """The ID of the rule."""

    action: Optional[Literal["bypass_waiting_room"]] = None
    """The action to take when the expression matches."""

    description: Optional[str] = None
    """The description of the rule."""

    enabled: Optional[bool] = None
    """When set to true, the rule is enabled."""

    expression: Optional[str] = None
    """Criteria defining when there is a match for the current rule."""

    last_updated: Optional[datetime] = None

    version: Optional[str] = None
    """The version of the rule."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .assets import (
    AssetsResource,
    AsyncAssetsResource,
    AssetsResourceWithRawResponse,
    AsyncAssetsResourceWithRawResponse,
    AssetsResourceWithStreamingResponse,
    AsyncAssetsResourceWithStreamingResponse,
)
from .custom_pages import (
    CustomPagesResource,
    AsyncCustomPagesResource,
    CustomPagesResourceWithRawResponse,
    AsyncCustomPagesResourceWithRawResponse,
    CustomPagesResourceWithStreamingResponse,
    AsyncCustomPagesResourceWithStreamingResponse,
)

__all__ = [
    "AssetsResource",
    "AsyncAssetsResource",
    "AssetsResourceWithRawResponse",
    "AsyncAssetsResourceWithRawResponse",
    "AssetsResourceWithStreamingResponse",
    "AsyncAssetsResourceWithStreamingResponse",
    "CustomPagesResource",
    "AsyncCustomPagesResource",
    "CustomPagesResourceWithRawResponse",
    "AsyncCustomPagesResourceWithRawResponse",
    "CustomPagesResourceWithStreamingResponse",
    "AsyncCustomPagesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Type, Optional, cast

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import path_template, maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._wrappers import ResultWrapper
from ...._base_client import make_request_options
from ....types.security_center.insights import severity_get_params
from ....types.intel.attack_surface_report.issue_type import IssueType
from ....types.security_center.insights.severity_get_response import SeverityGetResponse
from ....types.intel.attack_surface_report.severity_query_param import SeverityQueryParam

__all__ = ["SeverityResource", "AsyncSeverityResource"]


class SeverityResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SeverityResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return SeverityResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SeverityResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return SeverityResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        account_id: str | Omit = omit,
        zone_id: str | Omit = omit,
        dismissed: bool | Omit = omit,
        issue_class: SequenceNotStr[str] | Omit = omit,
        issue_class_neq: SequenceNotStr[str] | Omit = omit,
        issue_type: List[IssueType] | Omit = omit,
        issue_type_neq: List[IssueType] | Omit = omit,
        product: SequenceNotStr[str] | Omit = omit,
        product_neq: SequenceNotStr[str] | Omit = omit,
        severity: List[SeverityQueryParam] | Omit = omit,
        severity_neq: List[SeverityQueryParam] | Omit = omit,
        subject: SequenceNotStr[str] | Omit = omit,
        subject_neq: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SeverityGetResponse]:
        """
        Retrieves Security Center insight counts aggregated by severity level (critical,
        high, medium, low).

        Args:
          account_id: The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.

          zone_id: The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id and zone_id:
            raise ValueError("You cannot provide both account_id and zone_id")

        if account_id:
            account_or_zone = "accounts"
            account_or_zone_id = account_id
        else:
            if not zone_id:
                raise ValueError("You must provide either account_id or zone_id")

            account_or_zone = "zones"
            account_or_zone_id = zone_id
        return self._get(
            path_template(
                "/{account_or_zone}/{account_or_zone_id}/security-center/insights/severity",
                account_or_zone=account_or_zone,
                account_or_zone_id=account_or_zone_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "dismissed": dismissed,
                        "issue_class": issue_class,
                        "issue_class_neq": issue_class_neq,
                        "issue_type": issue_type,
                        "issue_type_neq": issue_type_neq,
                        "product": product,
                        "product_neq": product_neq,
                        "severity": severity,
                        "severity_neq": severity_neq,
                        "subject": subject,
                        "subject_neq": subject_neq,
                    },
                    severity_get_params.SeverityGetParams,
                ),
                post_parser=ResultWrapper[Optional[SeverityGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SeverityGetResponse]], ResultWrapper[SeverityGetResponse]),
        )


class AsyncSeverityResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSeverityResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSeverityResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSeverityResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cloudflare/cloudflare-python#with_streaming_response
        """
        return AsyncSeverityResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        account_id: str | Omit = omit,
        zone_id: str | Omit = omit,
        dismissed: bool | Omit = omit,
        issue_class: SequenceNotStr[str] | Omit = omit,
        issue_class_neq: SequenceNotStr[str] | Omit = omit,
        issue_type: List[IssueType] | Omit = omit,
        issue_type_neq: List[IssueType] | Omit = omit,
        product: SequenceNotStr[str] | Omit = omit,
        product_neq: SequenceNotStr[str] | Omit = omit,
        severity: List[SeverityQueryParam] | Omit = omit,
        severity_neq: List[SeverityQueryParam] | Omit = omit,
        subject: SequenceNotStr[str] | Omit = omit,
        subject_neq: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[SeverityGetResponse]:
        """
        Retrieves Security Center insight counts aggregated by severity level (critical,
        high, medium, low).

        Args:
          account_id: The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.

          zone_id: The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if account_id and zone_id:
            raise ValueError("You cannot provide both account_id and zone_id")

        if account_id:
            account_or_zone = "accounts"
            account_or_zone_id = account_id
        else:
            if not zone_id:
                raise ValueError("You must provide either account_id or zone_id")

            account_or_zone = "zones"
            account_or_zone_id = zone_id
        return await self._get(
            path_template(
                "/{account_or_zone}/{account_or_zone_id}/security-center/insights/severity",
                account_or_zone=account_or_zone,
                account_or_zone_id=account_or_zone_id,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "dismissed": dismissed,
                        "issue_class": issue_class,
                        "issue_class_neq": issue_class_neq,
                        "issue_type": issue_type,
                        "issue_type_neq": issue_type_neq,
                        "product": product,
                        "product_neq": product_neq,
                        "severity": severity,
                        "severity_neq": severity_neq,
                        "subject": subject,
                        "subject_neq": subject_neq,
                    },
                    severity_get_params.SeverityGetParams,
                ),
                post_parser=ResultWrapper[Optional[SeverityGetResponse]]._unwrapper,
            ),
            cast_to=cast(Type[Optional[SeverityGetResponse]], ResultWrapper[SeverityGetResponse]),
        )


class SeverityResourceWithRawResponse:
    def __init__(self, severity: SeverityResource) -> None:
        self._severity = severity

        self.get = to_raw_response_wrapper(
            severity.get,
        )


class AsyncSeverityResourceWithRawResponse:
    def __init__(self, severity: AsyncSeverityResource) -> None:
        self._severity = severity

        self.get = async_to_raw_response_wrapper(
            severity.get,
        )


class SeverityResourceWithStreamingResponse:
    def __init__(self, severity: SeverityResource) -> None:
        self._severity = severity

        self.get = to_streamed_response_wrapper(
            severity.get,
        )


class AsyncSeverityResourceWithStreamingResponse:
    def __init__(self, severity: AsyncSeverityResource) -> None:
        self._severity = severity

        self.get = async_to_streamed_response_wrapper(
            severity.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["LabelUpdateParams"]


class LabelUpdateParams(TypedDict, total=False):
    zone_id: Required[str]
    """Identifier."""

    managed: SequenceNotStr[str]
    """List of managed label names.

    Omitting this property or passing an empty array will result in all managed
    labels being removed from the operation
    """

    user: SequenceNotStr[str]
    """List of user label names.

    Omitting this property or passing an empty array will result in all user labels
    being removed from the operation
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Domain", "RegistrantContact", "TransferIn"]


class RegistrantContact(BaseModel):
    """Shows contact information for domain registrant."""

    address: str
    """Address."""

    city: str
    """City."""

    country: Optional[str] = None
    """The country in which the user lives."""

    first_name: Optional[str] = None
    """User's first name"""

    last_name: Optional[str] = None
    """User's last name"""

    organization: str
    """Name of organization."""

    phone: Optional[str] = None
    """User's telephone number"""

    state: str
    """State."""

    zip: Optional[str] = None
    """The zipcode or postal code where the user lives."""

    id: Optional[str] = None
    """Contact Identifier."""

    address2: Optional[str] = None
    """Optional address line for unit, floor, suite, etc."""

    email: Optional[str] = None
    """The contact email address of the user."""

    fax: Optional[str] = None
    """Contact fax number."""


class TransferIn(BaseModel):
    """Statuses for domain transfers into Cloudflare Registrar."""

    accept_foa: Optional[Literal["needed", "ok"]] = None
    """Form of authorization has been accepted by the registrant."""

    approve_transfer: Optional[Literal["needed", "ok", "pending", "trying", "rejected", "unknown"]] = None
    """Shows transfer status with the registry."""

    can_cancel_transfer: Optional[bool] = None
    """Indicates if cancellation is still possible."""

    disable_privacy: Optional[Literal["needed", "ok", "unknown"]] = None
    """Privacy guards are disabled at the foreign registrar."""

    enter_auth_code: Optional[Literal["needed", "ok", "pending", "trying", "rejected"]] = None
    """Auth code has been entered and verified."""

    unlock_domain: Optional[Literal["needed", "ok", "pending", "trying", "unknown"]] = None
    """Domain is unlocked at the foreign registrar."""


class Domain(BaseModel):
    id: Optional[str] = None
    """Domain identifier."""

    available: Optional[bool] = None
    """Shows if a domain is available for transferring into Cloudflare Registrar."""

    can_register: Optional[bool] = None
    """Indicates if the domain can be registered as a new domain."""

    created_at: Optional[datetime] = None
    """Shows time of creation."""

    current_registrar: Optional[str] = None
    """Shows name of current registrar."""

    expires_at: Optional[datetime] = None
    """Shows when domain name registration expires."""

    locked: Optional[bool] = None
    """Shows whether a registrar lock is in place for a domain."""

    registrant_contact: Optional[RegistrantContact] = None
    """Shows contact information for domain registrant."""

    registry_statuses: Optional[str] = None
    """A comma-separated list of registry status codes.

    A full list of status codes can be found at
    [EPP Status Codes](https://www.icann.org/resources/pages/epp-status-codes-2014-06-16-en).
    """

    supported_tld: Optional[bool] = None
    """Whether a particular TLD is currently supported by Cloudflare Registrar.

    Refer to [TLD Policies](https://www.cloudflare.com/tld-policies/) for a list of
    supported TLDs.
    """

    transfer_in: Optional[TransferIn] = None
    """Statuses for domain transfers into Cloudflare Registrar."""

    updated_at: Optional[datetime] = None
    """Last updated."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .global_warp_override_get_response import GlobalWARPOverrideGetResponse as GlobalWARPOverrideGetResponse
from .global_warp_override_create_params import GlobalWARPOverrideCreateParams as GlobalWARPOverrideCreateParams
from .global_warp_override_create_response import GlobalWARPOverrideCreateResponse as GlobalWARPOverrideCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["MessageAckParams", "Ack", "Retry"]


class MessageAckParams(TypedDict, total=False):
    account_id: Required[str]
    """A Resource identifier."""

    acks: Iterable[Ack]

    retries: Iterable[Retry]


class Ack(TypedDict, total=False):
    lease_id: str
    """An ID that represents an "in-flight" message that has been pulled from a Queue.

    You must hold on to this ID and use it to acknowledge this message.
    """


class Retry(TypedDict, total=False):
    delay_seconds: float
    """
    The number of seconds to delay before making the message available for another
    attempt.
    """

    lease_id: str
    """An ID that represents an "in-flight" message that has been pulled from a Queue.

    You must hold on to this ID and use it to acknowledge this message.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["RankingTimeseriesGroupsParams"]


class RankingTimeseriesGroupsParams(TypedDict, total=False):
    date_end: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dateEnd", format="iso8601")]
    """End of the date range (inclusive)."""

    date_range: Annotated[SequenceNotStr[str], PropertyInfo(alias="dateRange")]
    """Filters results by date range.

    For example, use `7d` and `7dcontrol` to compare this week with the previous
    week. Use this parameter or set specific start and end dates (`dateStart` and
    `dateEnd` parameters).
    """

    date_start: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dateStart", format="iso8601")]
    """Start of the date range."""

    domain_category: Annotated[SequenceNotStr[str], PropertyInfo(alias="domainCategory")]
    """Filters results by domain category."""

    domains: SequenceNotStr[str]
    """Filters results by domain name. Specify a comma-separated list of domain names."""

    format: Literal["JSON", "CSV"]
    """Format in which results will be returned."""

    limit: int
    """Limits the number of objects returned in the response."""

    location: SequenceNotStr[str]
    """Filters results by location.

    Specify a comma-separated list of alpha-2 location codes.
    """

    name: SequenceNotStr[str]
    """Array of names used to label the series in the response."""

    ranking_type: Annotated[Literal["POPULAR", "TRENDING_RISE", "TRENDING_STEADY"], PropertyInfo(alias="rankingType")]
    """The ranking type."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .create_index import CreateIndex as CreateIndex
from .index_query_params import IndexQueryParams as IndexQueryParams
from .index_create_params import IndexCreateParams as IndexCreateParams
from .index_info_response import IndexInfoResponse as IndexInfoResponse
from .index_insert_params import IndexInsertParams as IndexInsertParams
from .index_upsert_params import IndexUpsertParams as IndexUpsertParams
from .index_query_response import IndexQueryResponse as IndexQueryResponse
from .index_delete_response import IndexDeleteResponse as IndexDeleteResponse
from .index_insert_response import IndexInsertResponse as IndexInsertResponse
from .index_upsert_response import IndexUpsertResponse as IndexUpsertResponse
from .index_get_by_ids_params import IndexGetByIDsParams as IndexGetByIDsParams
from .index_list_vectors_params import IndexListVectorsParams as IndexListVectorsParams
from .index_delete_by_ids_params import IndexDeleteByIDsParams as IndexDeleteByIDsParams
from .index_list_vectors_response import IndexListVectorsResponse as IndexListVectorsResponse
from .index_delete_by_ids_response import IndexDeleteByIDsResponse as IndexDeleteByIDsResponse
from .index_dimension_configuration import IndexDimensionConfiguration as IndexDimensionConfiguration
from .index_dimension_configuration_param import IndexDimensionConfigurationParam as IndexDimensionConfigurationParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .traceroute import Traceroute as Traceroute
from .traceroute_create_params import TracerouteCreateParams as TracerouteCreateParams
from .endpoint_healthcheck_get_response import EndpointHealthcheckGetResponse as EndpointHealthcheckGetResponse
from .endpoint_healthcheck_create_params import EndpointHealthcheckCreateParams as EndpointHealthcheckCreateParams
from .endpoint_healthcheck_list_response import EndpointHealthcheckListResponse as EndpointHealthcheckListResponse
from .endpoint_healthcheck_update_params import EndpointHealthcheckUpdateParams as EndpointHealthcheckUpdateParams
from .endpoint_healthcheck_create_response import EndpointHealthcheckCreateResponse as EndpointHealthcheckCreateResponse
from .endpoint_healthcheck_delete_response import EndpointHealthcheckDeleteResponse as EndpointHealthcheckDeleteResponse
from .endpoint_healthcheck_update_response import EndpointHealthcheckUpdateResponse as EndpointHealthcheckUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["IntegrationListResponse"]


class IntegrationListResponse(BaseModel):
    id: str
    """The id of the integration, a UUIDv4."""

    account_tag: str
    """The Cloudflare account tag."""

    active: bool
    """Whether this integration is enabled and should export changes in risk score."""

    created_at: datetime
    """When the integration was created in RFC3339 format."""

    integration_type: Literal["Okta"]

    reference_id: str
    """
    A reference ID defined by the client. Should be set to the Access-Okta IDP
    integration ID. Useful when the risk-score integration needs to be associated
    with a secondary asset and recalled using that ID.
    """

    tenant_url: str
    """The base URL for the tenant. E.g. "https://tenant.okta.com"."""

    well_known_url: str
    """The URL for the Shared Signals Framework configuration, e.g.

    "/.well-known/sse-configuration/{integration_uuid}/".
    https://openid.net/specs/openid-sse-framework-1_0.html#rfc.section.6.2.1.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .request_types_response import RequestTypesResponse

__all__ = ["RequestTypes"]

RequestTypes: TypeAlias = List[RequestTypesResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from ...._models import BaseModel
from ...shared.response_info import ResponseInfo

__all__ = ["PackageGetResponse", "FirewallAPIResponseSingle", "Result"]


class FirewallAPIResponseSingle(BaseModel):
    errors: List[ResponseInfo]

    messages: List[ResponseInfo]

    result: Union[Optional[str], Optional[object]]

    success: Literal[True]
    """Defines whether the API call was successful."""


class Result(BaseModel):
    result: Optional[object] = None


PackageGetResponse: TypeAlias = Union[FirewallAPIResponseSingle, Result]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["BinaryStorageCreateResponse"]


class BinaryStorageCreateResponse(BaseModel):
    content_type: str

    md5: str

    sha1: str

    sha256: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .top import (
    TopResource,
    AsyncTopResource,
    TopResourceWithRawResponse,
    AsyncTopResourceWithRawResponse,
    TopResourceWithStreamingResponse,
    AsyncTopResourceWithStreamingResponse,
)
from .as112 import (
    AS112Resource,
    AsyncAS112Resource,
    AS112ResourceWithRawResponse,
    AsyncAS112ResourceWithRawResponse,
    AS112ResourceWithStreamingResponse,
    AsyncAS112ResourceWithStreamingResponse,
)
from .summary import (
    SummaryResource,
    AsyncSummaryResource,
    SummaryResourceWithRawResponse,
    AsyncSummaryResourceWithRawResponse,
    SummaryResourceWithStreamingResponse,
    AsyncSummaryResourceWithStreamingResponse,
)
from .timeseries_groups import (
    TimeseriesGroupsResource,
    AsyncTimeseriesGroupsResource,
    TimeseriesGroupsResourceWithRawResponse,
    AsyncTimeseriesGroupsResourceWithRawResponse,
    TimeseriesGroupsResourceWithStreamingResponse,
    AsyncTimeseriesGroupsResourceWithStreamingResponse,
)

__all__ = [
    "SummaryResource",
    "AsyncSummaryResource",
    "SummaryResourceWithRawResponse",
    "AsyncSummaryResourceWithRawResponse",
    "SummaryResourceWithStreamingResponse",
    "AsyncSummaryResourceWithStreamingResponse",
    "TimeseriesGroupsResource",
    "AsyncTimeseriesGroupsResource",
    "TimeseriesGroupsResourceWithRawResponse",
    "AsyncTimeseriesGroupsResourceWithRawResponse",
    "TimeseriesGroupsResourceWithStreamingResponse",
    "AsyncTimeseriesGroupsResourceWithStreamingResponse",
    "TopResource",
    "AsyncTopResource",
    "TopResourceWithRawResponse",
    "AsyncTopResourceWithRawResponse",
    "TopResourceWithStreamingResponse",
    "AsyncTopResourceWithStreamingResponse",
    "AS112Resource",
    "AsyncAS112Resource",
    "AS112ResourceWithRawResponse",
    "AsyncAS112ResourceWithRawResponse",
    "AS112ResourceWithStreamingResponse",
    "AsyncAS112ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["VirtualNetworkListParams"]


class VirtualNetworkListParams(TypedDict, total=False):
    account_id: Required[str]
    """Cloudflare account ID"""

    id: str
    """UUID of the virtual network."""

    is_default: bool
    """If `true`, only include the default virtual network.

    If `false`, exclude the default virtual network. If empty, all virtual networks
    will be included.
    """

    is_default_network: bool
    """If `true`, only include the default virtual network.

    If `false`, exclude the default virtual network. If empty, all virtual networks
    will be included.
    """

    is_deleted: bool
    """If `true`, only include deleted virtual networks.

    If `false`, exclude deleted virtual networks. If empty, all virtual networks
    will be included.
    """

    name: str
    """A user-friendly name for the virtual network."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["ObjectUploadResponse"]


class ObjectUploadResponse(BaseModel):
    """Result of a successful object upload."""

    etag: Optional[str] = None
    """The entity tag for the uploaded object."""

    key: Optional[str] = None
    """The key (name) of the uploaded object."""

    size: Optional[str] = None
    """The size of the uploaded object in bytes (as a string)."""

    storage_class: Optional[Literal["Standard", "InfrequentAccess"]] = None
    """Storage class for newly uploaded objects, unless specified otherwise."""

    uploaded: Optional[datetime] = None
    """The date and time the object was uploaded."""

    version: Optional[str] = None
    """The version UUID of the uploaded object."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .rules import (
    RulesResource,
    AsyncRulesResource,
    RulesResourceWithRawResponse,
    AsyncRulesResourceWithRawResponse,
    RulesResourceWithStreamingResponse,
    AsyncRulesResourceWithStreamingResponse,
)
from .filters import (
    FiltersResource,
    AsyncFiltersResource,
    FiltersResourceWithRawResponse,
    AsyncFiltersResourceWithRawResponse,
    FiltersResourceWithStreamingResponse,
    AsyncFiltersResourceWithStreamingResponse,
)
from .tcp_flow_protection import (
    TCPFlowProtectionResource,
    AsyncTCPFlowProtectionResource,
    TCPFlowProtectionResourceWithRawResponse,
    AsyncTCPFlowProtectionResourceWithRawResponse,
    TCPFlowProtectionResourceWithStreamingResponse,
    AsyncTCPFlowProtectionResourceWithStreamingResponse,
)

__all__ = [
    "FiltersResource",
    "AsyncFiltersResource",
    "FiltersResourceWithRawResponse",
    "AsyncFiltersResourceWithRawResponse",
    "FiltersResourceWithStreamingResponse",
    "AsyncFiltersResourceWithStreamingResponse",
    "RulesResource",
    "AsyncRulesResource",
    "RulesResourceWithRawResponse",
    "AsyncRulesResourceWithRawResponse",
    "RulesResourceWithStreamingResponse",
    "AsyncRulesResourceWithStreamingResponse",
    "TCPFlowProtectionResource",
    "AsyncTCPFlowProtectionResource",
    "TCPFlowProtectionResourceWithRawResponse",
    "AsyncTCPFlowProtectionResourceWithRawResponse",
    "TCPFlowProtectionResourceWithStreamingResponse",
    "AsyncTCPFlowProtectionResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .script import Script as Script
from .setting import Setting as Setting
from .connection import Connection as Connection
from .cookie_list_params import CookieListParams as CookieListParams
from .script_list_params import ScriptListParams as ScriptListParams
from .cookie_get_response import CookieGetResponse as CookieGetResponse
from .policy_get_response import PolicyGetResponse as PolicyGetResponse
from .script_get_response import ScriptGetResponse as ScriptGetResponse
from .cookie_list_response import CookieListResponse as CookieListResponse
from .policy_create_params import PolicyCreateParams as PolicyCreateParams
from .policy_list_response import PolicyListResponse as PolicyListResponse
from .policy_update_params import PolicyUpdateParams as PolicyUpdateParams
from .connection_list_params import ConnectionListParams as ConnectionListParams
from .policy_create_response import PolicyCreateResponse as PolicyCreateResponse
from .policy_update_response import PolicyUpdateResponse as PolicyUpdateResponse
from .page_shield_update_params import PageShieldUpdateParams as PageShieldUpdateParams
from .page_shield_update_response import PageShieldUpdateResponse as PageShieldUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["LogoCreateResponse"]


class LogoCreateResponse(BaseModel):
    message: str

    success: bool

    query_id: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["FirewallFilter"]


class FirewallFilter(BaseModel):
    id: Optional[str] = None
    """The unique identifier of the filter."""

    description: Optional[str] = None
    """An informative summary of the filter."""

    expression: Optional[str] = None
    """The filter expression.

    For more information, refer to
    [Expressions](https://developers.cloudflare.com/ruleset-engine/rules-language/expressions/).
    """

    paused: Optional[bool] = None
    """When true, indicates that the filter is currently paused."""

    ref: Optional[str] = None
    """A short reference tag. Allows you to select related filters."""
